#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MTEN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MTEN_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mten.hpp>

#endif
